@@ -17,14 +17,17 @@ from openpyxl import load_workbook
 from openpyxl.worksheet.cell_range import MultiCellRange
 from openpyxl.worksheet.worksheet import Worksheet
 
-from engine.domain.datamap import (DatamapFile, DatamapLine,
-                                   DatamapLineValueType)
+from engine.domain.datamap import DatamapFile, DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
-from engine.exceptions import (DatamapFileEncodingError,
-                               MalFormedCSVHeaderException,
-                               MissingCellKeyError, MissingLineError,
-                               MissingSheetFieldError,
-                               NoApplicableSheetsInTemplateFiles)
+from engine.exceptions import (
+    DatamapFileEncodingError,
+    MalFormedCSVHeaderException,
+    MissingCellKeyError,
+    MissingLineError,
+    MissingSheetFieldError,
+    NoApplicableSheetsInTemplateFiles,
+    DatamapNotCSVException,
+)
 from engine.utils import ECHO_FUNC_GREEN, ECHO_FUNC_YELLOW
 
 FILE_DATA = Dict[str, Union[str, Dict[str, Dict[str, str]]]]
@@ -53,7 +56,9 @@ def _dml_line_check(line: OrderedDict, headers: Dict[str, str]) -> None:
         and headers.get("sheet") in missing_fields
         and headers.get("cellref") in missing_fields
     ):
-        raise MissingLineError("Datamap contains a missing line. Please fix datamap before proceeding.")
+        raise MissingLineError(
+            "Datamap contains a missing line. Please fix datamap before proceeding."
+        )
     if headers.get("sheet") in missing_fields:
         raise MissingSheetFieldError(
             f"Line whose key is {line['cell_key']} is missing a sheet field. Cannot proceed."
@@ -69,7 +74,10 @@ def _dml_line_check(line: OrderedDict, headers: Dict[str, str]) -> None:
 
 def datamap_reader(dm_file: Union[Path, str]) -> List[DatamapLine]:
     "Given a datamap csv file, returns a list of DatamapLine objects."
-    headers = datamap_check(dm_file)
+    try:
+        headers = datamap_check(dm_file)
+    except DatamapNotCSVException:
+        raise
     data = []
     logger.info(f"Reading datamap {dm_file}")
     logger.info(f"Checking that datamap is valid.")
@@ -247,7 +255,7 @@ def _check_file_in_datafile(spreadsheet_file: Path, data_file: Path) -> bool:
             )
 
 
-def _get_xlsx_files(directory: Path) -> List[Path]:
+def get_xlsx_files(directory: Path) -> List[Path]:
     """Return a list of Path objects for each xlsx file in directory, or raise an exception."""
     output = []
     if not os.path.isabs(directory):
@@ -370,42 +378,45 @@ def datamap_check(dm_file):
     _good_type = ["type", "value_type", "cell_type", "celltype"]
     headers = {}
     using_type = True
-    with DatamapFile(dm_file) as datamap_file:
-        # initial check - have we got enough headers? If not - raise exception
-        top_row = next(datamap_file).rstrip().split(",")
-        if len(top_row) == 1:
-            # test for first char being ascii - if not, likely wrong encoding
+    try:
+        with DatamapFile(dm_file) as datamap_file:
+            # initial check - have we got enough headers? If not - raise exception
+            top_row = next(datamap_file).rstrip().split(",")
+            if len(top_row) == 1:
+                # test for first char being ascii - if not, likely wrong encoding
+                if not top_row[0][0].isascii():
+                    raise DatamapFileEncodingError(
+                        f"Incorrect encoding of datamap file. Please ensure "
+                        f"it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
+                    )
+                else:
+                    raise MalFormedCSVHeaderException(
+                        "Datamap contains only one header - need at least three to proceed. Quitting."
+                    )
+            if len(top_row) == 2:
+                raise MalFormedCSVHeaderException(
+                    "Datamap contains only two headers - need at least three to proceed. Quitting."
+                )
             if not top_row[0][0].isascii():
                 raise DatamapFileEncodingError(
                     f"Incorrect encoding of datamap file. Please ensure "
-                    f"it is saved in Excel using CSV (Comma delimited) type."
+                    f"it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
                 )
-            else:
-                raise MalFormedCSVHeaderException(
-                    "Datamap contains only one header - need at least three to proceed. Quitting."
-                )
-        if len(top_row) == 2:
-            raise MalFormedCSVHeaderException(
-                "Datamap contains only two headers - need at least three to proceed. Quitting."
-            )
-        if not top_row[0][0].isascii():
-            raise DatamapFileEncodingError(
-                f"Incorrect encoding of datamap file. Please ensure "
-                f"it is saved in Excel using CSV (Comma delimited) type."
-            )
-        if top_row[-1] not in _good_type:
-            # test if we are using type column here
-            headers.update(type=None)
-            using_type = False
-        if top_row[0] in _good_keys:
-            headers.update(key=top_row[0])
-        if top_row[1] in _good_sheet:
-            headers.update(sheet=top_row[1])
-        if top_row[2] in _good_cellref:
-            headers.update(cellref=top_row[2])
-        if using_type:
-            if top_row[3] in _good_type:
-                headers.update(type=top_row[3])
+            if top_row[-1] not in _good_type:
+                # test if we are using type column here
+                headers.update(type=None)
+                using_type = False
+            if top_row[0] in _good_keys:
+                headers.update(key=top_row[0])
+            if top_row[1] in _good_sheet:
+                headers.update(sheet=top_row[1])
+            if top_row[2] in _good_cellref:
+                headers.update(cellref=top_row[2])
+            if using_type:
+                if top_row[3] in _good_type:
+                    headers.update(type=top_row[3])
+    except DatamapNotCSVException:
+        raise
     if len(headers.keys()) >= 2:
         # final test - we don't want to proceed unless we have minimum headers
         if not all(
@@ -443,7 +454,7 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
     except BadZipFile:
         logger.critical(
             f"Cannot open {template_file} due to file not conforming to expected format. "
-            f"Not contunuing. Remove file from input directory and try again."
+            f"Not continuing. Remove file from input directory and try again."
         )
         raise RuntimeError
     checksum: str = _hash_single_file(f_path)
